@@ -141,6 +141,8 @@ def handle_key_public( ) :
 
 def handle_sslverify_fornumericip( ) :
 
+    # Also handles host.docker.internal
+
     endpoint_url = get_key( "endpoint/url" )
 
     if( not endpoint_url ) :
@@ -155,6 +157,10 @@ def handle_sslverify_fornumericip( ) :
     if( not purl.hostname ) :
         return
 
+    if purl.hostname == "host.docker.internal" :
+        set_key_alt( "endpoint/sslverify" , "no" )
+        return
+
     if( s_util.is_ip( purl.hostname ) ):
         set_key_alt( "endpoint/sslverify" , "no" )
         return
