@@ -572,7 +572,7 @@ def stdio_get_stdout( ) :
 
 ####################################################################
 
-def files_create( fp ) :
+def files_create( fp , trimpath = "" ) :
 
     # FIXME TODO have some restriction paths allowed - this breaks when creating UID directories for work spaces
     # FIXME TODO add tests for this...
@@ -593,8 +593,16 @@ def files_create( fp ) :
 
     ####################################################################
 
+    fp_processed = fp
+
+    if( trimpath != "" ) :
+        #s_log.write( "trimpath=" + trimpath )
+        fp_processed = fp.lstrip( trimpath )
+
+    ####################################################################
+
     sql = "INSERT INTO files ( fp , fc , fs , fh ) VALUES (?, ?, ?, ?)"
-    data_tuple = ( fp , fc , fs , fh )
+    data_tuple = ( fp_processed , fc , fs , fh )
 
     sql_execute( sql , data_tuple )
 
@@ -678,6 +686,20 @@ def files_restore( ) :
         with open( fp , "wb" ) as f :
             f.write( files_getcontent( fp ) )
 
+def files_createall( pat ) :
+    # Let's be clever and try to trim the pattern matching directory...
+
+    # FIXME TODO be careful... we are only checking for wildcard "**"
+    pat_trim=pat.rstrip("**")
+    if(pat_trim==pat):
+        pat_trim=""
+
+    files = s_util.glob_files( pat , True )
+    for f in files :
+        if os.path.isfile( f ) :
+            files_create( f , pat_trim )
+
+
 
 ####################################################################
 
