@@ -396,6 +396,10 @@ def decompress( d ) :
 
 def parent_path( ) :
 
+    # FIXME TODO this copy pasta should be cleaned up
+
+    trc=None
+
     for teil in inspect.stack():
         # skip system calls
         if teil[1].startswith("<"):
@@ -412,6 +416,10 @@ def parent_path( ) :
                 "name": scriptname,
                 "source": trc}
 
+
+    if(trc==None):
+        return(os.getcwd())
+
     # from here on, we are in the interpreted case
     scriptdir, trc = os.path.split(trc)
     # if trc did not contain directory information,
@@ -467,6 +475,10 @@ def url_parse( u ) :
 def sleep( t = 1 ) :
     time.sleep( t ) 
 
+def idle( ) :
+    while True:
+        s_log.write("IDLE")
+        time.sleep( 86400 )
 
 def datetime_now_db( td = 0 ) :
 
@@ -511,11 +523,24 @@ def datetime_initstartend( p , es , ee , ew ) :
 
 ################
 
+def path_mkdirs( dp ) :
+
+    path = Path( dp )
+    path.mkdir(parents=True,exist_ok=True)
+
+
+def path_dirname( dp ) :
+    return( os.path.dirname(dp) )
+
+
 def dir_exists( dp ) :
     if( not os.path.isdir( dp ) ) :
         return( False )
     return( True )
 
+def dir_chdir( dp ) :
+    os.chdir( dp )
+
 def dir_make( dp ) :
     os.makedirs(dp, exist_ok=True)
 # Return file getcontents given filename and parent script __FILE__
